/*
 * Copyright 2002 Eric Hodel. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name of Eric Hodel nor the names of his
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ERIC HODEL AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ERIC HODEL OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

// Yes, most of these functions are from Livelizard (slightly modified) unless otherwise stated.
const PASSWORD_CID = "@mozilla.org/passwordmanager;1";
const PREF_CID = "@mozilla.org/preferences;1";

var gPasswordManager;
var gPasswordManagerInternal;
var gPreferences;

function getPref() {
  if (!gPreferences) {
    try {
      gPreferences = Components.classes[PREF_CID].getService();
      gPreferences = gPreferences.QueryInterface(
        Components.interfaces.nsIPref);
    } catch (e) {}
  }

  return gPreferences;
}

function getPasswordManager() {
  if (!gPasswordManager) {
    try {
      gPasswordManager = Components.classes[PASSWORD_CID].getService();
      gPasswordManager = gPasswordManager.QueryInterface(
        Components.interfaces.nsIPasswordManager);
    } catch (e) {
      dump("getPasswordManager() failed\n");
    }
  }

  return gPasswordManager;
}

function getPasswordManagerInternal() {
  if (!gPasswordManagerInternal) {
    try {
      gPasswordManagerInternal =
        Components.classes[PASSWORD_CID].getService();
      gPasswordManagerInternal = gPasswordManagerInternal.QueryInterface(
        Components.interfaces.nsIPasswordManagerInternal);
    } catch (e) {
      dump("getPasswordManagerInternal() failed\n");
    }
  }

  return gPasswordManagerInternal;
}

function getPassword(loginData) {
  if (!loginData)
    return null;

  var pmInternal = getPasswordManagerInternal();
  if (!pmInternal)
    return null;

  var host = {value:''};
  var user = {value:''};
  var password = {value:''};

  try {
    pmInternal.findPasswordEntry(loginData.LJURL, '', '',
      host, user, password);
    loginData.username = user.value;
    loginData.password = password.value;
    return loginData;
  } catch(e) {
    dump("findPasswordEntry() failed\n");
  }

  return null;
}

function savePassword(loginData) {
  if (!loginData || !loginData.LJURL || !loginData.username)
    return false;

  var pm = getPasswordManager();

  if (!pm)
    return false;

  try {
    pm.removeUser(loginData.LJURL, loginData.username);
  } catch(e) {
    dump("removeUser() failed\n");
  }

  if (loginData.savePassword) {
    try {
      pm.addUser(loginData.LJURL, loginData.username, loginData.password);
    } catch(e) {
      dump("addUser failed\n");
    }

    return true;
  }
  
  return false;
}

function LoadCredentials() {
  var loginData = {
    LJURL: LJURL,
    username : '',
    password : ''
  };
 
  loginData = getPassword(loginData);
  if (!loginData)
    return false;

  document.getElementById("username").value = loginData.username;
  document.getElementById("password").value = loginData.password;

  return true;
}

function SaveCredentials(username, password, savepass) {
  var loginData = {
    LJURL : LJURL,
    username : username,
    password : password,
    savePassword : savepass
  };

  return savePassword(loginData);
}

function getResponseData(heading, responseText) {
	var i = 0;
	var data = null;
	var responseData = responseText.split("\n");
	while (i != responseData.length) {
		if (responseData[i] == heading) {
			data = responseData[i + 1];
			return data;
		}
	i++;
}

  return null;
}

// Grabbed this off the net. It's just to get rid of any whitespace at the start and end of strings, to stop people from just pressing space a few times then
// hitting post to send a blank entry off to LJ.
function strtrim() {
	return this.replace(/^\s+/,'').replace(/\s+$/,'');
}
String.prototype.trim = strtrim;